@@ -1,8 +1,12 @@
 .__global__ <-
-c("d.units", "day.name", "day.abb", "wdConst", "hblue", "hred", 
-"hgreen")
+c("d.units", "d.periodic", "d.prefix", "day.name", "day.abb", 
+"wdConst", "hblue", "hred", "hgreen")
 .DoCount <-
 function(y, x, wts) {
+
+  # O(n log n):
+  # http://www.listserv.uga.edu/cgi-bin/wa?A2=ind0506d&L=sas-l&P=30503
+  
   
   btree <- function(n) {
     ranks <- rep(0L, n)
@@ -32,7 +36,7 @@ function(y, x, wts) {
   res <- .Call("conc", y[ord,], as.double(wts[ord]), 
         as.integer(index), as.integer(n2))
   
-  return(list(pi.c = NA, pi.d = NA, C = res[1], D = res[3]))
+  return(list(pi.c = NA, pi.d = NA, C = res[2], D = res[1]))
   
 }
 .fmt <-
@@ -52,6 +56,78 @@ function(x, digits=3, sdigits=7, big.mark="'") {
     formatC(x)
   }  
 }
+.nctCI <-
+function(tval.1, df, conf) {       
+  
+  # Function for finding the upper and lower confidence limits for the noncentrality from noncentral t distributions.
+  # Especially helpful when forming confidence intervals around the standardized effect size, Cohen's d.
+  
+  ###################################################################################################################
+  # The following code was adapted from code written by Michael Smithson:
+  # Australian National University, sometime around the early part of October, 2001
+  # Adapted by Joe Rausch & Ken Kelley: University of Notre Dame, in January 2002.
+  # Available at: JRausch@nd.edu & KKelley@nd.edu
+  ###################################################################################################################
+  
+  
+  # tval.1 is the observed t value, df is the degrees of freedom (group size need not be equal), and conf is simply 1 - alpha
+  
+  #         Result <- matrix(NA,1,4)
+  tval <- abs(tval.1)
+  
+  
+  ############################This part Finds the Lower bound for the confidence interval###########################
+  ulim <- 1 - (1-conf)/2
+  
+  # This first part finds a lower value from which to start.
+  lc <- c(-tval,tval/2,tval)
+  while(pt(tval, df, lc[1])<ulim)    {
+    lc <- c(lc[1]-tval,lc[1],lc[3])
+  }
+  
+  # This next part finds the lower limit for the ncp.
+  diff <- 1
+  while(diff > .00000001)    {
+    if(pt(tval, df, lc[2]) <ulim)
+      lc <- c(lc[1],(lc[1]+lc[2])/2,lc[2])
+    else lc <- c(lc[2],(lc[2]+lc[3])/2,lc[3])
+    diff <- abs(pt(tval,df,lc[2]) - ulim)
+    ucdf <- pt(tval,df,lc[2])
+  }
+  res.1 <- ifelse(tval.1 >= 0,lc[2],-lc[2])
+  
+  ############################This part Finds the Upper bound for the confidence interval###########################
+  llim <- (1-conf)/2
+  
+  # This first part finds an upper value from which to start.
+  uc <- c(tval,1.5*tval,2*tval)
+  while(pt(tval,df,uc[3])>llim)   {
+    uc <- c(uc[1],uc[3],uc[3]+tval)
+  }
+  
+  # This next part finds the upper limit for the ncp.
+  diff <- 1
+  while(diff > .00000001)         {
+    if(pt(tval,df,uc[2])<llim)
+      uc <- c(uc[1],(uc[1]+uc[2])/2,uc[2])
+    else uc <- c(uc[2],(uc[2]+uc[3])/2,uc[3])
+    diff <- abs(pt(tval,df,uc[2]) - llim)
+    lcdf <- pt(tval,df,uc[2])
+  }
+  res <- ifelse(tval.1 >= 0,uc[2],-uc[2])
+  
+  
+  #################################This part Compiles the results into a matrix#####################################
+  
+  return(c(lwr.ci=min(res, res.1), lprob=ucdf, upr.ci=max(res, res.1), uprob=lcdf))
+  
+  #        Result[1,1] <- min(res,res.1)
+  #         Result[1,2] <- ucdf
+  #         Result[1,3] <- max(res,res.1)
+  #         Result[1,4] <- lcdf
+  # dimnames(Result) <- list("Values", c("Lower.Limit", "Prob.Low.Limit", "Upper.Limit", "Prob.Up.Limit"))
+  #         Result
+}
 .pAD <-
 function(q, n=Inf, lower.tail=TRUE, fast=TRUE) {
   q <- as.numeric(q)
@@ -895,131 +971,131 @@ structure(list(NA_real_, NA_real_, k3 = c(0.166666666666667,
 "k6", "k7", "k8", "k9", "k10", "k11", "k12", "k13", "k14", "k15"
 ))
 .Random.seed <-
-c(403L, 10L, 770862634L, 1530479509L, 610813999L, 614252854L, 
-1209524576L, 1709473699L, -660354879L, -1347618640L, 1321666510L, 
--615507143L, -1222151349L, -2121488134L, 926806524L, 1672630847L, 
-963262229L, 1574421548L, -30720766L, 503043549L, 258581719L, 
-1676578750L, 937404920L, 1607699931L, 1754965049L, -666647160L, 
--1562259146L, -159356047L, -1544238685L, -512084750L, -1785468860L, 
--641627385L, -1602057507L, -2076535852L, 478614266L, -764934587L, 
-161767071L, -329472986L, -1741811536L, 1706707283L, -455388047L, 
-1247316384L, -1903426242L, -693287863L, -1319038725L, -1677616950L, 
--923091412L, 980124207L, -1174127899L, -1410850916L, -2038449678L, 
--1487481747L, -273156697L, 494100430L, -2118238936L, -1174266069L, 
-119752009L, 1297345112L, 938222342L, 36736737L, 437701235L, -1335856414L, 
-301821524L, 1576499031L, 1871776589L, -706838812L, -1172324662L, 
--1245446347L, 1707996559L, -1331580266L, -199112128L, -244786429L, 
--9229535L, -1070478320L, -126354450L, -1693635687L, -2013105109L, 
-265089306L, 1154581468L, -922327585L, -1201663563L, -1166917812L, 
--354151006L, 699823357L, -744367625L, -119695586L, 1531980248L, 
--988970181L, -1918917415L, 1316464744L, 1868610966L, 286582033L, 
-194053827L, -1373190446L, 969768804L, -1326890329L, -1552421891L, 
--988799500L, 1991654106L, 1148451877L, 2014196031L, 1273603782L, 
-562850640L, 1762775923L, -613513839L, 1555630016L, 1693675934L, 
--744670359L, 572845979L, -1165912406L, 109027532L, 2141282703L, 
-2121708997L, 652401020L, -1676842542L, -1573923507L, 1488013319L, 
--1412192274L, 1394593480L, -1827986997L, 2022577193L, 452625016L, 
--1124454490L, 1550838209L, 473718355L, 114799874L, 1725658164L, 
--1819261513L, -1704040019L, -2102678844L, 490761962L, -1153580715L, 
--715704593L, 171197686L, 808424480L, -1149499933L, 516126337L, 
--1429896976L, -876052594L, -1876586247L, -821765493L, -1689732422L, 
--88083012L, 675847935L, -1830677931L, 1758881132L, -2013696574L, 
--1438806499L, 422368919L, 1630953470L, 716737464L, -1027807333L, 
-601067001L, 659656008L, -434386826L, -1532611151L, 142130147L, 
-918096050L, 1262904580L, -934304185L, 101789981L, 776634260L, 
-977134394L, 2142842757L, 1404599391L, 412759782L, -475906704L, 
-384681619L, -1015783631L, 539649504L, -1830075778L, 1345761545L, 
-1637192507L, 2125277962L, 268870380L, 87400303L, -772292443L, 
--1967101348L, 1363462706L, 845668653L, -572004377L, -575312114L, 
-1248182504L, -4656405L, -778364023L, -1604860136L, -1043248570L, 
--539776351L, -1747219149L, -431057758L, -483435628L, -825384425L, 
-1412343309L, -1298742492L, -775012598L, -1689447819L, -1082519089L, 
--1420322090L, 2082995840L, 832544963L, -1040351647L, 1074198224L, 
--1336127442L, 1392743897L, 1171024363L, 465378394L, -733346276L, 
-176482079L, 453589877L, -1667702260L, -1048218654L, 984162493L, 
-629182263L, -878741538L, -397687528L, 1434757243L, 1041813017L, 
--608803160L, 1376445526L, -928423727L, -1063306109L, -604856558L, 
-1673079460L, 542914151L, 322774973L, 2064349492L, -1263404390L, 
-1244281061L, -1411519873L, 1311838140L, -1295110060L, 415105986L, 
--654924768L, 1121848508L, -1370527152L, -113717278L, 2030057064L, 
-1373751884L, 979140860L, -880398350L, 1126284544L, 1158698868L, 
--1674469368L, 1270404538L, -1882317360L, -700431380L, -1769480300L, 
-1625304018L, -427165856L, 225645900L, -129532640L, 975115138L, 
-1449716456L, -729615124L, 1403238972L, -1481581710L, 171584112L, 
--1225258972L, 2028910392L, -1506722662L, 692302544L, 162685116L, 
-796960404L, 1911047810L, 2131877056L, -1788096196L, -779165552L, 
--1151837662L, -491809272L, -72609524L, 810369692L, -977019374L, 
-2093198720L, -1653494252L, -1023023576L, -2047093446L, 1575012304L, 
--683081108L, 1973888820L, -315059566L, -1204569760L, -1988345524L, 
-1131945952L, 973066146L, -2133887064L, 1506753420L, -908355908L, 
-38394738L, 1100376304L, 1016453188L, -1596498600L, 1889535034L, 
-1264558960L, -1963236292L, 1302108948L, 468257218L, 152301792L, 
--762206340L, 1987047120L, -1639414110L, 1260774440L, -1243199220L, 
-1957045180L, -2106053326L, -446898240L, 1804849716L, 1478659016L, 
--1824488262L, 650293136L, -1527691796L, -590512044L, -1533047150L, 
-521419552L, 816659916L, 1002908640L, -1003072830L, -1010079192L, 
-529653420L, -561237316L, 96936434L, 1963305264L, 1870142628L, 
-552620728L, -360715430L, 2013310352L, 1766564220L, -942121708L, 
-1449314626L, -54574336L, 561617852L, -2097116336L, -1090625246L, 
--1863938744L, 1540675596L, 1969535068L, 93787346L, 161662976L, 
-1757465428L, -167890456L, 1794533370L, -134289712L, -1891740372L, 
-205117684L, 1746081682L, 1655508064L, 441928972L, 730195680L, 
-1547169122L, -1877851480L, -58709428L, -594884740L, 780733234L, 
--97300880L, 258383172L, 1908829144L, -1377116038L, 1650087472L, 
-2095831740L, 13154132L, -1167639998L, -705225824L, 204331196L, 
-438563280L, 1334691170L, 1019651048L, -45774900L, 346031868L, 
--1260425230L, 249592960L, -2083411724L, -1004178296L, -1869695686L, 
--1389403312L, -314184596L, 2114097300L, 250325330L, -734150944L, 
-287850700L, 1125095584L, 1141578114L, -1037231896L, -764229396L, 
-1880737852L, 275783794L, -1511372688L, 765993508L, 1556906552L, 
-98802202L, -1874100016L, 824624700L, -871207788L, 1069696130L, 
--1978841152L, -832324292L, -1205408112L, -1405795294L, -105418744L, 
--1533289332L, -435318756L, 501748882L, -4739968L, 2059240468L, 
--2081561816L, -1329081286L, 182668496L, 1704580204L, -963295564L, 
--2040639470L, 515448800L, 1503931340L, 820927968L, -2125800414L, 
-529851688L, -1145366260L, 1181904444L, -2130676494L, 1288759536L, 
--1482873020L, 1204916312L, 967885370L, 481982704L, -1766206788L, 
-2106866196L, -1490195262L, 1579869792L, 1580758396L, -775031600L, 
--238459870L, -2141247320L, -1490563700L, -1196731972L, 552146994L, 
--718765248L, -2141466956L, -778411704L, 404628154L, 974028560L, 
--431726356L, -1795135404L, 335906578L, 595698080L, -259250228L, 
--1377468576L, 1030315202L, 1543269928L, 1143151020L, 237093692L, 
--853257358L, 826462000L, 1288675364L, -1474171336L, 183407322L, 
--2044282992L, -480250628L, -572506732L, -1056033982L, -237784646L, 
--372875272L, -1028678751L, -1308289709L, -313766796L, -434790910L, 
-599765143L, 1314865761L, -1397482842L, 1182974628L, 457115477L, 
-1665928191L, -1656907112L, -1817837642L, -1327811517L, -1678021243L, 
-446477858L, -1861653232L, -953074503L, -1358298773L, -598855588L, 
--653034102L, -673150593L, 2002392265L, 1733585246L, 1510328844L, 
-1620192733L, 1508160743L, 2048463120L, 1799827502L, 512411355L, 
-1220083645L, -1776133846L, 2145947080L, -1340435727L, 593116259L, 
-1873627236L, -600554606L, 2045593703L, -1743251407L, 1204447606L, 
-1388435092L, 2127928485L, 733757871L, 954505832L, -846798266L, 
-375474163L, 422983509L, 882633010L, 648379648L, 94043625L, -353941413L, 
-108321452L, 149701818L, -1992440209L, -1157508103L, -2015020402L, 
--1569342628L, -605128755L, 211646263L, -942545472L, -956233058L, 
--914889877L, 1250327277L, 921628506L, 1035346968L, -1105518207L, 
-1847285555L, 299765076L, 1948862306L, 1436933111L, 932979777L, 
-1661178054L, 1278123524L, 799726005L, -1983551841L, -1938217224L, 
-77302486L, 1813667683L, 750200613L, 1564302530L, -121415248L, 
-1196306905L, 707051339L, -1151601220L, 558900714L, 1502093855L, 
--841938775L, -1036320706L, -1116344020L, -1649378435L, 698388935L, 
--1151695696L, 2001785550L, 1643481083L, 1820053597L, -1705560182L, 
--1713080408L, -528499439L, -1354152957L, -116330748L, -710180046L, 
-959603079L, -1072396335L, -467064490L, 492439348L, -1245697467L, 
-61200015L, -217595896L, -40082394L, -115933997L, -974922187L, 
-1693074L, 1436150112L, -394555191L, 248488955L, -1093434420L, 
-26082906L, -1354210481L, -558859751L, 1223817262L, -360712644L, 
--795276371L, -2050251689L, -567258720L, 1307732734L, 1849395659L, 
-1270247373L, -1359338758L, 876665144L, 1311269601L, -1003952749L, 
--77640268L, 1269845698L, -2054119721L, 741003041L, 535783142L, 
-96116708L, 1224544021L, 1324640063L, 731443928L, -242321674L, 
-571040003L, -1544199611L, 1140372066L, 916517328L, -1646309639L, 
--838153173L, -1977168996L, 681370570L, -2134139713L, -69255671L, 
-1387919134L, 789954252L, -57803107L, -1078428889L, -2023418544L, 
-410016750L, -523541349L, -931950851L, -471411222L, -823531896L, 
--716705743L, -6305117L, 1938240164L, -141941934L, 346581671L, 
--444360975L, 277083702L, -252401911L)
+c(403L, 10L, -236118234L, 1465507905L, 843796947L, 1455143810L, 
+871436212L, -817428681L, -1249190355L, -579596476L, 1914702954L, 
+612726485L, -1230970769L, 241131894L, -1384158560L, 611604323L, 
+-1442415615L, -1492277392L, -886771954L, -1386608263L, -1127596789L, 
+527484474L, -1518461636L, 2028868223L, 2058000853L, 1171412972L, 
+-612701886L, 211515037L, -1898814697L, -116542850L, 952549944L, 
+-1166502629L, 591356537L, -1806131512L, -550545674L, -1152450767L, 
+821229411L, -1928696526L, -1526624636L, 203647687L, 963611037L, 
+-1714610924L, 2131325882L, -165669371L, -1131030561L, 1405824614L, 
+1402468848L, 50976531L, -704046927L, 2056014688L, 1618196734L, 
+-2040141687L, -1876985925L, -1588792950L, -963485588L, 2687471L, 
+-1833362907L, -1187107108L, 993789106L, 2140145581L, 1535458151L, 
+137042062L, 1853543784L, -1251736213L, -545331447L, -578479720L, 
+-1283882810L, -847470047L, -2128926029L, -560408542L, -943103468L, 
+-1720686953L, 1375795341L, -48685660L, -1712496758L, 1996491765L, 
+547283535L, 115070294L, -1800433664L, 889205059L, -613876511L, 
+-1008085424L, 94792366L, 851291737L, -747571605L, 221985754L, 
+-432386916L, 1073940127L, -1779577611L, 1069378956L, 1185298530L, 
+1467635773L, 821600951L, 1664051550L, -574246760L, -232801285L, 
+-644077159L, 1974753832L, 189332182L, -2143899823L, -897125885L, 
+-1979742830L, -925154524L, 1775637991L, 1754456637L, 1610243252L, 
+-2030462182L, -177557403L, -1279362817L, -79660666L, 383979280L, 
+-1380836429L, 1979881553L, 1172540416L, -862761762L, 520068905L, 
+1440760539L, -324503062L, 394510732L, 1090119375L, 1604844165L, 
+-1895722692L, 363281426L, 1355813645L, 863625287L, 281088558L, 
+88529800L, -1006799221L, 1451755625L, -1918135240L, 1592939750L, 
+-172925823L, -1487176685L, -535258174L, -581655436L, 679549559L, 
+-195493011L, 169169924L, 2014301994L, -794801003L, 395610927L, 
+971233846L, -1424220576L, 774159523L, 1140561857L, 1716921264L, 
+2105427662L, 1841108025L, -1082365365L, 2145402874L, 7854844L, 
+-1637322945L, -1503002603L, -1124658388L, 608188418L, 1031865053L, 
+1514891735L, -694377282L, 60104440L, -1721611045L, 1436700473L, 
+-1654003064L, -1253257674L, -990855567L, -150659933L, 549197298L, 
+-1932520124L, 702797319L, 174707677L, -1634485036L, 1312973818L, 
+-989293755L, -1417246817L, -1425240794L, 2118833584L, 987418195L, 
+-1846539919L, 1964597408L, 201535550L, 1478121289L, 1503149563L, 
+-1249254966L, 1399656236L, 506359599L, -1154851355L, 194896028L, 
+-535477006L, -1879917203L, 1901431463L, -1418976050L, 803998248L, 
+1034279467L, 389066825L, -433163944L, -1601755130L, 297294305L, 
+1915986803L, -408963102L, -583065772L, 791335511L, -151010739L, 
+423175652L, -492634166L, -2025143755L, 1653393551L, -1541457514L, 
+-2116025024L, 257349635L, -939275743L, 581111056L, 46695150L, 
+-464527719L, -1235460309L, -2114479590L, 1218365660L, 907150559L, 
+1985544885L, -2142399412L, 1765009570L, 2132191229L, -144059145L, 
+-1364803042L, -400458536L, 2064007227L, 370985433L, 1160032104L, 
+888677014L, 1283238929L, 1681063363L, -1100335540L, -1148068996L, 
+744903986L, -1214357904L, 759106372L, 1885705176L, -1571868806L, 
+208015920L, 939150268L, -255155628L, -805155774L, -931596128L, 
+-1415728452L, -1648321072L, -376146078L, 804205288L, -1433463604L, 
+437374460L, -1852999182L, -470575488L, -290241036L, -1738743160L, 
+354776890L, -930504880L, -1490215828L, -1434227308L, -1975804846L, 
+1889135072L, 1209726156L, 1701200032L, 1262922114L, 697252072L, 
+-1361005844L, 879670588L, 2123562098L, 982213744L, -648696796L, 
+-1561722824L, 553671450L, 1359404240L, 676465468L, 1053620116L, 
+-2116989054L, -289135168L, 1773679164L, -882185840L, -508483038L, 
+-2011165432L, 707517068L, 928368412L, -1532518254L, 173941120L, 
+-1873968620L, -1956527320L, -2017065414L, 1734379984L, 767972716L, 
+-1998494796L, 1738984466L, -1561284128L, 1014088652L, 902283488L, 
+-404203486L, 1931144488L, -2072807924L, 225309500L, -890764302L, 
+1400979184L, -829982140L, 1131241048L, 171422522L, 449266160L, 
+-1320722756L, -580907756L, 315064002L, -1533943712L, -833353860L, 
+-1783817264L, -1210708702L, 571532968L, 413879180L, -454992708L, 
+-2090830030L, -1592683968L, -958003020L, -1660212664L, -1919144518L, 
+-633032176L, 971390700L, -480600748L, 1575986450L, -1268885088L, 
+-550797620L, 589198944L, -240753726L, -1703689432L, 430742444L, 
+40984380L, -269177486L, 974593840L, -352541404L, -1233155272L, 
+1157283546L, -3935344L, -1408730372L, 577934228L, -564936638L, 
+808665344L, 1305556028L, 2078029136L, 527487138L, -1681851064L, 
+-186287348L, -1465552164L, 624558418L, 1109377152L, 1991097428L, 
+-175641624L, 1058260218L, 548688L, 619851564L, -276812428L, 1907806098L, 
+-1125794720L, 1966441868L, 1557773152L, 1740137954L, 306308008L, 
+301625548L, 2067594236L, -2009935438L, 2046959088L, -1004982332L, 
+-1888919208L, -468318854L, -1951141968L, 1565578684L, 1438585940L, 
+1234724802L, -978999264L, -912021316L, -242837936L, 1499836386L, 
+-286185368L, 1816256588L, -2057612036L, -237078542L, -1209680640L, 
+1161123188L, 1618872328L, -621268038L, 1151198672L, 1529171948L, 
+-2016432748L, 873667026L, 1158865248L, 1041357644L, 125471008L, 
+652699522L, 1045382888L, -1100025620L, 2072995900L, -1285550222L, 
+-2089296272L, -1141171164L, -692385992L, 794727578L, 615686864L, 
+996133052L, 1773835924L, -1656373630L, 257689792L, 836427580L, 
+-1296043888L, -1023494622L, -1379353592L, 1041653004L, -1611195236L, 
+1064055314L, 178897792L, 1676244500L, -1974323672L, -1686266566L, 
+-1988454960L, -242716564L, 1574380852L, 1475035794L, 1296209760L, 
+753078092L, -1625550880L, 594856866L, 1848372136L, -598107764L, 
+-1236089668L, 1992503666L, 1083764976L, -418168764L, -1018589864L, 
+-2070748614L, -860774544L, -1342477252L, 1333168916L, 1351636418L, 
+1327781600L, -194038916L, -906685744L, -1014229854L, -1800443864L, 
+2037057804L, 649335740L, -889174734L, 1926365632L, 1962865204L, 
+-1712437304L, 269083834L, 700504464L, 1327210988L, -984105388L, 
+-1637356398L, 1712012064L, -404790836L, -1325023776L, 166112962L, 
+-436735960L, 454123180L, -1594527556L, 866833906L, 544287406L, 
+-315861060L, -1748922323L, -761081897L, -1027955168L, 1197164414L, 
+2038769995L, 474155853L, -946914950L, -295461960L, 376086881L, 
+-359305965L, 1813574964L, -111763646L, 474988375L, 881397409L, 
+766599014L, 1649416548L, 832519317L, -314952257L, 1337661784L, 
+-1989257354L, -1023777405L, -1327800379L, 814048482L, -2084740784L, 
+690552953L, 2024473515L, -1042011876L, 1619582538L, -278971841L, 
+1097395849L, 704813726L, 1126442828L, -989020387L, 712703655L, 
+829552080L, -1290572434L, -2070478821L, 133067133L, -410294422L, 
+872866312L, 1683080881L, -214449885L, -211791324L, -1292748590L, 
+1274573095L, -1732347023L, -499029578L, 515932500L, 1523449829L, 
+1247009263L, 1887019304L, -141969018L, 299738547L, 2063132949L, 
+-1535468686L, -1050953792L, -1519093719L, -968182629L, -2050895508L, 
+1130223994L, 414038703L, 410087865L, 97221582L, 1901232924L, 
+1954470541L, 1029243639L, 766813696L, 299368542L, -600335573L, 
+1219762221L, 1401143450L, -222444456L, -355417151L, -2080428941L, 
+1467340180L, -1996821470L, 2386743L, 1350577665L, -513163514L, 
+-1356344508L, 153101941L, -1485277217L, 1996114744L, -193020650L, 
+396583203L, -1112560923L, -1600986366L, -1053103760L, -442384103L, 
+-419045109L, 660423164L, 747215402L, 928983647L, -841172503L, 
+-1691995394L, 2121890540L, 347982397L, 1680566791L, 241221104L, 
+-220123762L, -1245006917L, -351081059L, 1560834890L, 463652712L, 
+1920706897L, 538511939L, -165007548L, 866337778L, -71149113L, 
+-955658351L, 442922774L, -1192967308L, -260408827L, 372681295L, 
+-977074616L, -662575130L, -1902565101L, 1818146421L, -1452405678L, 
+-1248147808L, -1713183863L, -352206917L, -711393268L, 1749921178L, 
+-938750705L, 1048482649L, -796365330L, 942426236L, 1372019949L, 
+510155671L, 1208288352L, -947378626L, 695398155L, -1111616115L, 
+-42262854L, 523414776L, -1910945119L, -883439021L, 2032186740L, 
+-130163966L, -615445609L, -568156831L, -1148502618L, -618004572L, 
+923298389L, -1233306881L, -768196712L, 1404817590L, 1507767619L, 
+24786053L, -1816851166L, -1978034672L, -603130439L, 420218475L, 
+-1700988580L, 1480593546L, -359958401L, 1407728073L, 684735070L, 
+1749709068L, 1512318173L, -1344638489L, 711256592L, -2146285778L, 
+-1953936421L, 1887915197L, -1192292822L, 290199815L)
 .txtline <-
 function(txt, width, space="", ind="") {
   paste(
@@ -1028,7 +1104,7 @@ function(txt, width, space="", ind="") {
     sep="" )
 }
 .WrdPrepRep <-
-function( wrd, main="Bericht" ){
+function(wrd, main="Bericht" ){
   
   # only internal user out from GetNewWrd()
   # creates new word instance and prepares document for report
@@ -1081,10 +1157,98 @@ function( wrd, main="Bericht" ){
   wrdView[["SeekView"]] <- wdConst$wdSeekCurrentPageFooter
   wrd[["Selection"]]$TypeText( gettextf("%s/%s\t\t",format(Sys.time(), "%d.%m.%Y"), Sys.getenv("username")) )
   wrd[["Selection"]][["Fields"]]$Add( wrd[["Selection"]][["Range"]], wdConst$wdFieldEmpty, "PAGE" )
-  wrd[["Selection"]]$TypeText("\n\n")
+  # Roland wollte das nicht (23.11.2014):
+  # wrd[["Selection"]]$TypeText("\n\n")
   wrdView[["SeekView"]] <- wdConst$wdSeekMainDocument
   
   wrd[["Selection"]]$InsertBreak( wdConst$wdPageBreak)
   invisible()
   
 }
+.writeCB <-
+function (dat, ...) {
+  
+  sn <- Sys.info()["sysname"]
+  if (sn == "Darwin") {
+    file <- pipe("pbcopy")
+    cat(dat, file = file, ...)
+    close(file)
+  }
+  else if (sn == "Windows") {
+    cat(dat, file = "clipboard", ...)
+  }
+  else {
+    stop("Writing to the clipboard is not implemented for your system (", 
+         sn, ") in this package.")
+  }
+}
+.YuenTTestB <-
+function(x, y, trim = 0, conf.level = 0.95, nboot=599 
+                       , alternative = c("two.sided", "less", "greater"), mu = 0, na.rm = FALSE){
+
+  
+  TrimSE <- function(x, trim = 0, na.rm = FALSE) {
+
+    #  Estimate the standard error of the gamma trimmed mean
+    #  The default amount of trimming is trim = 0.2
+    
+    if(na.rm) x <- na.omit(x)
+    
+    winvar <- var(Winsorize(x, probs = c(trim, 1-trim)))
+    
+    trimse <- sqrt(winvar) / ((1 - 2 * trim) * sqrt(length(x)))
+    trimse
+  }
+
+  
+  alternative <- match.arg(alternative)
+  method <- "Yuen Two Sample bootstrap t-test"
+  dname <- paste(deparse(substitute(x)), "and", deparse(substitute(y)))
+
+  if(na.rm) x <- na.omit(x)
+  if(na.rm) y <- na.omit(y)
+  
+  meanx <- mean(x, trim = trim)
+  meany <- mean(y, trim = trim)
+  
+  tstat <- (meanx - meany ) / sqrt(TrimSE(x, trim = trim)^2 + TrimSE(y, trim = trim)^2)
+
+  sampx <- matrix(sample(x - meanx, size=length(x) * nboot, replace=TRUE), nrow=nboot)
+  sampy <- matrix(sample(y - meany, size=length(y) * nboot, replace=TRUE), nrow=nboot)
+  
+  top <- apply(sampx, 1, mean, trim) - apply(sampy, 1, mean, trim)
+  botx <- apply(sampx, 1, TrimSE, trim)
+  boty <- apply(sampy, 1, TrimSE, trim)
+  tval <- top / sqrt(botx^2 + boty^2)
+
+
+  alpha <- 1 - conf.level
+  se <- sqrt((TrimSE(x, trim = trim))^2 + (TrimSE(y, trim = trim))^2)
+
+  if(alternative == "two.sided") {
+    tval <- abs(tval)
+    icrit <- floor((1 - alpha) * nboot + .5)
+    cint <- meanx - meany + c(-1, 1) * tval[icrit] * se
+    pval <- (sum(abs(tstat) <= abs(tval))) / nboot
+    
+  } else {
+    tval <- sort(tval)
+    ibot <- floor(alpha/2 * nboot + .5)
+    itop <- floor((1 - alpha/2) * nboot + .5)
+    cint <- meanx - meany - tval[c(itop, ibot)] * se
+    
+  }  
+
+  names(tstat) <- "t"
+  names(mu) <- "difference in means"
+  estimate <- c(meanx, meany)
+  names(estimate) <- c("mean of x", "mean of y")
+
+  attr(cint, "conf.level") <- conf.level
+  rval <- list(statistic = tstat, p.value = pval, 
+               conf.int = cint, estimate = estimate, null.value = mu, 
+               alternative = alternative, method = method, data.name = dname)
+  class(rval) <- "htest"
+  return(rval)
+
+}
