@@ -1,7 +1,8 @@
 PlotDesc.factor <-
 function (x, main = deparse(substitute(x)), 
                 ord = c("desc", "level", "name", "asc", "none"), maxrows = 10, lablen = 25, 
-                type=c("bar","dot"), col=getOption("col1", hblue), ..., wrd=NULL)  {
+                type=c("bar","dot"), col=NULL, border=NULL, ..., wrd=NULL)  {
+  
   
   if (nlevels(factor(x)) <= 2) {
     PlotDesc.logical(x, main = main, ..., wrd=wrd)
@@ -36,25 +37,29 @@ function (x, main = deparse(substitute(x)),
     
     switch(match.arg(arg = type, choices = c("bar", "dot")), 
            dot = {
+             if(is.null(col)) col <- getOption("col1", hblue)
+             if(is.null(border)) border <- "black"
              b <- barplot( rev(tab), horiz=TRUE, border=NA, col="white", las=1, 
                            xlim=range(pretty(tab)) + c(-1,1) * diff(range(pretty(tab))) * 0.04, 
                            xpd=FALSE, xlab="frequency", cex.names=cex, cex.axis=cex, cex.lab=cex, tck=-0.04)
              abline(h=b, v=0, col="grey", lty="dotted")
-             points( x=rev(tab), y=b, yaxt = "n", col="black", pch=21, bg=col, cex=1.3)
+             points( x=rev(tab), y=b, yaxt = "n", col=border, pch=21, bg=col, cex=1.3)
              box()  
              
              par(mai=c(1.5, 0.1, 0.2, .3)+.02) 
              b <- barplot( rev(ptab), horiz=TRUE, border=NA, col="white", las=1, names="", xlim=c(-0.04,1.04), xlab="percent", cex.names=cex, cex.axis=cex, cex.lab=cex, tck=-0.04)
              abline(h=b, v=0, col="grey", lty="dotted")
-             points( x=rev(ptab), y=b, col="black", pch=21, bg=col, cex=1.3)
+             points( x=rev(ptab), y=b, col=border, pch=21, bg=col, cex=1.3)
              box()
              
            }, bar = { # type = "bar" 
-             barplot( rev(tab), horiz=TRUE, border=NA, col="grey80", las=1, xlim=range(pretty(tab)), xpd=FALSE, xlab="frequency", cex.names=cex, cex.axis=cex, cex.lab=cex, tck=-0.04)
+             if(is.null(col)) col <- "grey80"
+             if(is.null(border)) border <- NA
+             barplot( rev(tab), horiz=TRUE, col=col, border=border, las=1, xlim=range(pretty(tab)), xpd=FALSE, xlab="frequency", cex.names=cex, cex.axis=cex, cex.lab=cex, tck=-0.04)
              grid(ny=NA)
              
              par(mai=c(1.5, 0.15, 0.2, .3) + .02) 
-             barplot( rev(ptab), horiz=TRUE, border=NA, col="grey80", las=1, names="", xlim=c(0,1), xlab="percent", cex.names=cex, cex.axis=cex, cex.lab=cex, tck=-0.04)
+             barplot( rev(ptab), horiz=TRUE, col=col, border=border, las=1, names="", xlim=c(0,1), xlab="percent", cex.names=cex, cex.axis=cex, cex.lab=cex, tck=-0.04)
              grid(ny=NA)
              
            })
