@@ -1,7 +1,7 @@
 SignTest.formula <-
-function (formula, data, subset, na.action, ...) 
-{
-  # this is a taken analogue to wilcox.test.formula  
+function (formula, data, subset, na.action, ...) {
+  
+  # this is designed just like wilcox.test.formula  
 
   if (missing(formula) || (length(formula) != 3L) || (length(attr(terms(formula[-2L]), 
       "term.labels")) != 1L)) 
